"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCommitSteps = void 0;
var chalk_1 = __importDefault(require("chalk"));
var utils_1 = require("./utils");
function getCommitSteps() {
    return [
        {
            type: "select",
            name: "type",
            message: "Select the type of change that you're committing",
            choices: (0, utils_1.getCommitTypesMapped)(),
        },
        {
            type: "input",
            name: "scope",
            message: "What is the scope of this change (e.g. component or file name)",
            result: function (value) { return (value ? "(".concat(value.trim(), ")") : ""); },
        },
        {
            type: "input",
            name: "description",
            message: "Write a short, imperative tense description of the change\n",
            validate: function (value) { return !!value && !!value.trim(); },
            result: function (value) {
                return (value.charAt(0).toLowerCase() + value.slice(1)).trim();
            },
        },
        {
            type: "input",
            name: "body",
            message: 'Provide a LONGER description of the change (optional). Use "|" to break new line:\n',
            result: function (value) {
                return value ? "\n\n".concat(value.trim().split("|").join("\n")) : "";
            },
        },
        {
            type: "input",
            name: "footer",
            message: "List any ISSUES CLOSED by this change (optional). E.g.: #31, #34:\n",
            result: function (value) { return (value ? "\n\n".concat(value.trim()) : ""); },
        },
        {
            type: "confirm",
            name: "confirmCommit",
            initial: true,
            message: function () {
                // @ts-ignore
                var answers = this.state.answers;
                var commitMsg = "\n\n".concat((0, utils_1.buildCommitMessage)(answers), "\n\n");
                var question = "Are you sure you want to proceed with the commit above?";
                return chalk_1.default.yellow(commitMsg) + question;
            },
        },
    ];
}
exports.getCommitSteps = getCommitSteps;
